@@ -43,7 +43,7 @@ def permutations(selection_size: int, items: list) -> list:
 def next_lexicographic_permutation(items: list, copy=True) -> list:
     if copy:
         items = items.copy()
-    begin = -1
+    begin, end = -1, len(items) - 1
     for i in range(len(items) - 2, -1, -1):
         if items[i] < items[i + 1]:
             begin = i
@@ -51,8 +51,7 @@ def next_lexicographic_permutation(items: list, copy=True) -> list:
     if begin < 0:
         reverse(items)
     else:
-        first_greater_from_end = binary_search_subarray_exclusive_boundery(
-            items, begin=begin + 1, end=len(items) - 1, target=items[begin], is_ascending=False, is_smaller=False)
+        first_greater_from_end = binary_search_subarray_exclusive_boundery(items, begin + 1, end, items[begin], is_ascending=False, is_smaller=False)
         swap(items, begin, first_greater_from_end)
         reverse(items, begin + 1, len(items) - 1)
     return items
@@ -210,22 +209,23 @@ def enumerations(item_lists: list, recursive=False) -> list:
             for item in item_lists[index]:
                 item_list[index] = item
                 _enumerations(output, item_lists, item_list, index + 1)
+
     if not item_lists:
         return list()
     output = list()
     if recursive:
         _enumerations(output, item_lists, [None] * len(item_lists), 0)
     else:
-        stack = list()
+        stack, item_lists_size = list(), len(item_lists)
         for item in item_lists[0][::-1]:
             stack.append([item])
         while len(stack) > 0:
             template = stack.pop()
-            size = len(template)
-            if size == len(item_lists):
+            template_size = len(template)
+            if template_size == item_lists_size:
                 output.append(template)
             else:
-                for item in item_lists[size][::-1]:
+                for item in item_lists[template_size][::-1]:
                     stack.append(template + [item])
     return output
 
